"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path = require("path");
var ts = require("typescript");
var transformAST_1 = require("../transformAST");
var defaultOptions = {
    target: ts.ScriptTarget.Latest,
    module: ts.ModuleKind.CommonJS
};
describe('transformAST', function () {
    var fileName = path.join(__dirname, '../../src/__tests__/data/transformAST.tsx'); // it's running in ./temp
    var program = ts.createProgram([fileName], defaultOptions);
    var checker = program.getTypeChecker();
    var sourceFile = program.getSourceFile(fileName);
    var target = transformAST_1.transformAST(sourceFile, checker);
    it('should provide data about variables', function () {
        var result = target.variables;
        chai_1.assert.equal(result.length, 8);
        var r1 = result[0];
        chai_1.assert.equal(r1.name, 'unexportedVar');
        chai_1.assert.equal(r1.exported, false);
        chai_1.assert.equal(r1.kind, 'literal');
        chai_1.assert.equal(r1.initializerFlags, ts.TypeFlags.NumberLiteral);
        var r2 = result[1];
        chai_1.assert.equal(r2.name, 'exportedVar');
        chai_1.assert.equal(r2.exported, true);
        chai_1.assert.equal(r2.kind, 'literal');
        chai_1.assert.equal(r2.initializerFlags, ts.TypeFlags.NumberLiteral);
        var r3 = result[2];
        chai_1.assert.equal(r3.name, 'unexportedVarFunction');
        chai_1.assert.equal(r3.exported, false);
        chai_1.assert.equal(r3.kind, 'arrowFunction');
        chai_1.assert.equal(r3.comment, 'unexportedVarFunction comment');
        chai_1.assert.equal(r3.arrowFunctionType, 'number');
        chai_1.assert.deepEqual(r3.arrowFunctionParams, ['string']);
        var r4 = result[3];
        chai_1.assert.equal(r4.name, 'exportedVarFunction');
        chai_1.assert.equal(r4.exported, true);
        chai_1.assert.equal(r4.kind, 'arrowFunction');
        chai_1.assert.equal(r4.comment, 'exportedVarFunction comment');
        chai_1.assert.equal(r4.arrowFunctionType, 'string');
        chai_1.assert.deepEqual(r4.arrowFunctionParams, ['number', 'string']);
        // hoc class
        var r5 = result[4];
        chai_1.assert.equal(r5.name, 'exportedHoc1');
        chai_1.assert.equal(r5.exported, true);
        chai_1.assert.equal(r5.type, 'ExportedClass');
        chai_1.assert.equal(r5.kind, 'callExpression');
        chai_1.assert.equal(r5.comment, 'exportedHoc1 comment');
        chai_1.assert.deepEqual(r5.callExpressionArguments, ['ExportedClass']);
        // hoc function
        var r6 = result[5];
        chai_1.assert.equal(r6.name, 'exportedHoc2');
        chai_1.assert.equal(r6.exported, true);
        chai_1.assert.equal(r6.type, 'exportedFunction');
        chai_1.assert.equal(r6.kind, 'callExpression');
        chai_1.assert.equal(r6.comment, 'exportedHoc2 comment');
        chai_1.assert.deepEqual(r6.callExpressionArguments, ['exportedFunction']);
        // external hoc class
        var r7 = result[6];
        chai_1.assert.equal(r7.name, 'exportedExternalHoc1');
        chai_1.assert.equal(r7.exported, true);
        chai_1.assert.equal(r7.type, 'ExportedClass');
        chai_1.assert.equal(r7.kind, 'callExpression');
        chai_1.assert.equal(r7.comment, 'exportedExternalHoc1 comment');
        chai_1.assert.deepEqual(r7.callExpressionArguments, ['ExportedClass']);
        // external hoc function
        var r8 = result[7];
        chai_1.assert.equal(r8.name, 'exportedExternalHoc2');
        chai_1.assert.equal(r8.exported, true);
        chai_1.assert.equal(r8.type, 'exportedFunction');
        chai_1.assert.equal(r8.kind, 'callExpression');
        chai_1.assert.equal(r8.comment, 'exportedExternalHoc2 comment');
        chai_1.assert.deepEqual(r8.callExpressionArguments, ['exportedFunction']);
    });
    it('should provide data about interfaces', function () {
        var result = target.interfaces;
        chai_1.assert.equal(result.length, 4);
        var r1 = result[0];
        chai_1.assert.equal(r1.name, 'UnexportedInterface');
        chai_1.assert.equal(r1.exported, false);
        chai_1.assert.deepEqual(r1.properties, [{
                'name': 'prop1',
                'type': 'string',
                'isRequired': true,
                'isOwn': true,
                'comment': 'prop1 comment',
                'values': [],
            }]);
        var r2 = result[1];
        chai_1.assert.equal(r2.name, 'ExportedInterface');
        chai_1.assert.equal(r2.exported, true);
        chai_1.assert.deepEqual(r2.properties, [{
                'name': 'prop1',
                'type': 'string',
                'isRequired': true,
                'isOwn': true,
                'comment': 'prop1 comment',
                'values': [],
            }, {
                'name': 'prop2',
                'type': 'string',
                'isRequired': true,
                'isOwn': true,
                'comment': 'prop2 comment',
                'values': [],
            }]);
        var r3 = result[2];
        chai_1.assert.equal(r3.name, 'ExportedInheritedInterface');
        chai_1.assert.equal(r3.exported, true);
        chai_1.assert.deepEqual(r3.properties, [{
                'name': 'ownProp1',
                'type': 'string',
                'isRequired': true,
                'isOwn': true,
                'comment': 'ownProp1 comment',
                'values': [],
            }, {
                'name': 'prop1',
                'type': 'string',
                'isRequired': true,
                'isOwn': false,
                'comment': 'prop1 comment',
                'values': [],
            }, {
                'name': 'prop2',
                'type': 'string',
                'isRequired': true,
                'isOwn': false,
                'comment': 'prop2 comment',
                'values': [],
            },
        ]);
        var r4 = result[3];
        chai_1.assert.equal(r4.name, 'ExternalInterface');
        chai_1.assert.equal(r4.exported, true);
    });
    it('should provide data about classes', function () {
        var result = target.classes;
        chai_1.assert.equal(result.length, 4);
        var r1 = result[1];
        chai_1.assert.equal(r1.name, 'UnexportedClass');
        chai_1.assert.equal(r1.exported, false);
        chai_1.assert.equal(r1.comment, 'UnexportedClass comment');
        chai_1.assert.deepEqual(r1.methods, [{ name: 'method1' }]);
        var r2 = result[2];
        chai_1.assert.equal(r2.name, 'ExportedClass');
        chai_1.assert.equal(r2.exported, true);
        chai_1.assert.equal(r2.comment, 'ExportedClass comment');
        chai_1.assert.deepEqual(r2.methods, [{ name: 'method1' }, { name: 'method2' }]);
        var r4 = result[3];
        chai_1.assert.equal(r4.name, 'ExportedClassWithExternalDependency');
        chai_1.assert.equal(r4.exported, true);
        chai_1.assert.equal(r4.comment, 'ExportedClassWithExternalDependency comment');
        chai_1.assert.deepEqual(r4.baseType.typeArguments.length, 2);
    });
    it('should provide data about types', function () {
        chai_1.assert.equal(target.types.length, 1);
        var t1 = target.types[0];
        chai_1.assert.equal(t1.name, 'ExportedType1');
        // because ExportedType1 inherites from built in type and can 
        // change over time we don't use exact number here
        chai_1.assert.isTrue(t1.properties.length > 200);
        chai_1.assert.equal(t1.properties.filter(function (i) { return i.isOwn; }).length, 2);
    });
});
//# sourceMappingURL=transformAST.spec.js.map